@@ -1,7 +1,7 @@
 // -*- c++ -*-
 #ifndef _GLIBMM_OBJECT_H
 #define _GLIBMM_OBJECT_H
-/* $Id: object.h,v 1.10.4.3 2006/04/12 12:50:10 murrayc Exp $ */
+/* $Id: object.h,v 1.11 2005/12/16 09:04:00 murrayc Exp $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
@@ -28,8 +28,6 @@
 #include <glibmm/containerhandle_shared.h> //Because its specializations may be here.
 #include <glibmm/value.h>
 
-#include <glibmmconfig.h>
-
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 extern "C"
 {
@@ -86,7 +84,7 @@ private:
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
 
-class GLIBMM_API Object : virtual public ObjectBase
+class Object : virtual public ObjectBase
 {
 public:
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
